==> haskell-serialise-0.2.6.1-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 serialise
version:              0.2.6.1
visibility:           public
id:                   serialise-0.2.6.1-CYml4CGY9WIK1aQToLBsde
key:                  serialise-0.2.6.1-CYml4CGY9WIK1aQToLBsde
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  806327a6542efbb6135194cc72be0235
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-serialise
hs-libraries:         HSserialise-0.2.6.1-CYml4CGY9WIK1aQToLBsde
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cborg-0.2.9.0-AVCy7PihHBXDJjQkLtTSRn containers-0.6.7
    ghc-prim-0.9.1 half-0.3.2-E1LlIe0hzkw3sgpiTlypC8
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    primitive-0.7.4.0-K4IT7bUBj0c2CIJh0yt8eH
    strict-0.5-4BdDs8LFxiW3drE3TQrJG6 text-2.0.2
    these-1.2-HHBDt6FdrNkB5x4JzaevG8 time-1.12.2
    unordered-containers-0.2.20-4cFR6FXPxn69oePlCyMUKW
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-serialise-0.2.6.1-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 serialise
version:              0.2.6.1
visibility:           public
id:                   serialise-0.2.6.1-ZxnyFaDgX8EaKTlW3qraU
key:                  serialise-0.2.6.1-ZxnyFaDgX8EaKTlW3qraU
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  91945d21e9bdbc73ca674abaa9385fd8
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-serialise
hs-libraries:         HSserialise-0.2.6.1-ZxnyFaDgX8EaKTlW3qraU
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cborg-0.2.9.0-VgE1ZKGxSP5YtdDndmCaU containers-0.6.7 ghc-prim-0.9.1
    half-0.3.2-E1LlIe0hzkw3sgpiTlypC8
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    primitive-0.7.4.0-K4IT7bUBj0c2CIJh0yt8eH
    strict-0.5-327XbhI6RNzK6TodlJYYET text-2.0.2
    these-1.2-L4EL7Iwezbp3j1oAddIVlT time-1.12.2
    unordered-containers-0.2.20-2oScjwZejU42oDENjBi2vG
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
